@@ -1,5 +1,7 @@
 """
-Main interface for datapipeline service literal definitions.
+Type annotations for datapipeline service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/literals.html)
 
 Usage::
 
